@@ -1,8 +1,8 @@
 /*
    Handle so called 'shell archives'.
 
-   Copyright (C) 1994, 1995, 1996, 2002, 2005, 2006, 2007, 2010
-   Free Software Foundation, Inc.
+   Copyright (C) 1994-1996, 2002, 2005-2007, 2010-2011
+      Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,17 +29,29 @@
 #  define USE_UNLOCKED_IO 1
 #endif
 
+#include <alloca.h>
 #include <getopt.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/utsname.h>
+#include <time.h>
+#include <unistd.h>
 
 #include "basename.h"
+#include "dirname.h"
 #include "error.h"
 #include "gettext.h"
+#include "inttostr.h"
 #include "locale.h"
+#include "pathmax.h"
+#include "quotearg.h"
+#include "strftime.h"
 #include "system.h"
-#include "xstrtol.h"
 #include "unlocked-io.h"
+#include "xalloc.h"
+#include "xgetcwd.h"
+#include "xstrtol.h"
 
 #ifdef BINARY_MODE_POPEN
 static char const freadonly_mode[]  = "rb";
