@@ -2,7 +2,7 @@
 static const char cright_years_z[] =
 
 /* Handle so called `shell archives'.
-   Copyright (C) */ "1994, 1995, 1996, 2002, 2005, 2006, 2007, 2010";
+   Copyright (C) */ "1994-1996, 2002, 2005-2007, 2010";
 
 /* Free Software Foundation, Inc.
 
@@ -20,6 +20,26 @@ static const char cright_years_z[] =
    along with this program; if not, see:  http://www.gnu.org/licenses.
 */
 
+/*
+   A note about translated strings:
+
+   There are several categories of English text that get emitted by this
+   program:
+
+   1)  Error messages by this program.  These should all be literals
+       in this program text and should be surrounded by _() macro calls.
+
+   2)  Error messages emitted by the shell script emitted by this
+       program.  These messages *MUST ALL BE DEFINED* in the 'shar-msg'
+       table defined in scripts.def.  The emitted script will try to
+       translate them before echoing them out to the user.
+
+   3)  Shell script comments that are inserted into the output.
+       These English comments are *NEVER* translated.  They appear both
+       as literal text in this program, and as literal script text in
+       the 'text' table in "scripts.def".  Localization of "shar" has
+       no effect on these comment strings.
+ */
 #include "local.h"
 
 #include <ctype.h>
@@ -43,7 +63,7 @@ static const char cright_years_z[] =
 #endif
 
 /*
- *  _() and N_() strings are both extracted into the .pot file.
+ *  _() wrapped strings are extracted into the .pot file.
  */
 #define _(str)  gettext (str)
 
@@ -135,6 +155,17 @@ struct tm *localtime ();
 # define TYPE_MAXIMUM(t) ((t) (~ (t) 0 - TYPE_MINIMUM (t)))
 #endif
 
+static char const explain_fmt_fmt[] = "# %%-%ds\n# %%-%ds\n";
+static char explain_text_fmt[sizeof(explain_fmt_fmt)];
+
+static char const explain_1[] =
+  "This is part 1 of a multipart archive.";
+static int  const explain_1_len = sizeof(explain_1) - 1;
+
+static char const explain_2[] =
+  "Do not concatenate these parts, unpack them in orderwith `/bin/sh'.";
+static int  const explain_2_len = sizeof(explain_2) - 1;
+
 typedef enum {
   QUOT_ID_LNAME,
   QUOT_ID_RNAME,
@@ -441,8 +472,8 @@ static void
 echo_text (const char* format_pz, const char* arg_pz, int cascade)
 {
   static char const continue_z[] = " &&\n";
-  unsigned int len = (unsigned)snprintf
-    (scribble, scribble_size - sizeof (continue_z), format_pz, arg_pz);
+  unsigned int len = (unsigned)snprintf (
+    scribble, scribble_size - sizeof (continue_z), format_pz, arg_pz);
 
   if (cascade && (len < scribble_size - sizeof (continue_z)))
     {
@@ -694,9 +725,9 @@ generate_configure (void)
   if (md5_count_mode)
     fprintf (output, md5check_z, SM_not_verifying_sums);
 
-  if (no_i18n)
-    fputs ("echo=echo\n", output);
-  else
+  fputs (clobber_check_z, output);
+
+  if (! no_i18n)
     {
       fputs (i18n_z, output);
       /* Above the name of the program of the package which supports the
@@ -706,7 +737,7 @@ generate_configure (void)
   if (!quiet_unshar_mode)
     {
       if (vanilla_operation_mode)
-	fputs ("shar_tty= shar_n= shar_c='\n'\n", output);
+	fputs (dev_tty_nocheck_z, output);
       else
 	{
 	  if (query_user_mode)
@@ -732,8 +763,7 @@ generate_configure (void)
     {
       static char const lock_dir[] = "${lock_dir}";
 
-      echo_status ("test ! -d ${lock_dir}", NULL, SM_lock_dir_exists,
-                   lock_dir, 1);
+      echo_status (ck_lockdir_z, NULL, SM_lock_dir_exists, lock_dir, 1);
 
       /* Create locking directory.  */
       if (vanilla_operation_mode)
@@ -966,39 +996,36 @@ generate_full_header (int argc, char * const * argv)
   else
     error (0, errno, _("Cannot get current directory name"));
 
-  fputs ("#\n# Existing files ", output);
-  if (check_existing_mode)
-    fputs ("will *not* be overwritten, unless `-c' is specified.\n",
-	   output);
-  else if (query_user_mode)
-    fputs ("MAY be overwritten.\n", output);
-  else
-    fputs ("WILL be overwritten.\n", output);
+  {
+    static char const fmt[] =
+      "#\n# Existing files %s.\n";
+    char const * msg;
+
+    if (check_existing_mode)
+      msg = "will *not* be overwritten, unless `-c' is specified";
+    else if (query_user_mode)
+      msg = "MAY be overwritten";
+    else
+      msg = "WILL be overwritten";
+    fprintf(output, fmt, msg);
+  }
 
   if (query_user_mode)
     fputs ("# The unsharer will be INTERACTIVELY queried.\n",
 	   output);
 
-  if (vanilla_operation_mode)
-    {
-      fputs (
-        "# This format requires very little intelligence at unshar time.\n# ",
-	     output);
-      if (check_existing_mode || split_file_mode)
-	fputs ("\"if test\", ", output);
-      if (split_file_mode)
-	fputs ("\"cat\", \"rm\", ", output);
-      fputs ("\"echo\", \"mkdir\", and \"sed\" may be needed.\n", output);
-    }
-
   if (split_file_mode)
     {
+      int len = snprintf (explain_text_fmt, sizeof (explain_text_fmt),
+                          explain_fmt_fmt, explain_1_len, explain_2_len);
+      if ((unsigned)len >= sizeof (explain_text_fmt))
+        strcpy (explain_text_fmt, "#%-256s\n#%-256s\n");
 
-      /* May be split, explain.  */
+      /* May be split, provide for white space for an explanation.  */
 
       fputs ("#\n", output);
       archive_type_position = ftello (output);
-      fprintf (output, "%-75s\n%-75s\n", "#", "#");
+      fprintf (output, explain_text_fmt, "", "");
     }
 
   fputs (contents_z, output);
@@ -1150,8 +1177,7 @@ emit_char_ct_validation (
   }
 
   snprintf (scribble, scribble_size, SM_bad_size, restore_name, wc);
-  fprintf (output, "test `%s %s` -ne %s && \\\n  ${echo} %s\n",
-           cct_cmd, restore_name, wc, scribble);
+  fprintf (output, ck_chct_z, cct_cmd, restore_name, wc, scribble);
   pclose (pfp);
 }
 
@@ -1390,17 +1416,14 @@ open_next_shar_file (char const * restore, off_t * size_left, int * split_flag)
       fprintf (output, echo_string_z, scribble);
     }
 
-  fprintf (output, "echo %d > ${lock_dir}/seq\nexit 0\n", part_number + 1);
+  fprintf (output, end_part_z, part_number + 1);
 
   if (part_number == 1)
     {
       /* Rewrite the info lines on the first header.  */
 
       fseeko (output, archive_type_position, SEEK_SET);
-      fprintf (output, "%-75s\n%-75s\n",
-               "# This is part 1 of a multipart archive.",
-               "# Do not concatenate these parts, unpack them in order "
-               "with `/bin/sh'.");
+      fprintf (output, explain_text_fmt, explain_1, explain_2);
     }
   close_output ();
 
@@ -1877,38 +1900,31 @@ usage (int status)
     {
       printf (_("Usage: %s [OPTION]... [FILE]...\n"), program_name);
       fputs (_("\
-Mandatory arguments to long options are mandatory for short options too.\n"),
-	     stdout);
-      fputs (_("\
+Mandatory arguments to long options are mandatory for short options too.\n\
 \n\
 Giving feedback:\n\
       --help              display this help and exit\n\
       --version           output version information and exit\n\
-  -q, --quiet, --silent   do not output verbose messages locally\n"),
+  -q, --quiet, --silent   do not output verbose messages locally\n\
+\n\
+Selecting files:\n"),
 	     stdout);
 #if HAVE_COMPRESS
       fputs (_("\
-\n\
-Selecting files:\n\
-  -p, --intermix-type     allow -[BTzZ] in file lists to change mode\n\
-  -S, --stdin-file-list   read file list from standard input\n"),
+  -p, --intermix-type     allow -[BTzZ] in file lists to change mode\n"),
 	     stdout);
 #else
       fputs (_("\
-\n\
-Selecting files:\n\
-  -p, --intermix-type     allow -[BTz] in file lists to change mode\n\
-  -S, --stdin-file-list   read file list from standard input\n"),
+  -p, --intermix-type     allow -[BTz] in file lists to change mode\n"),
 	     stdout);
 #endif
       fputs (_("\
+  -S, --stdin-file-list   read file list from standard input\n\
 \n\
 Splitting output:\n\
   -o, --output-prefix=PREFIX    output to file PREFIX.01 through PREFIX.NN\n\
   -l, --whole-size-limit=SIZE   split archive, not files, to SIZE kilobytes\n\
-  -L, --split-size-limit=SIZE   split archive, or files, to SIZE kilobytes\n"),
-	     stdout);
-      fputs (_("\
+  -L, --split-size-limit=SIZE   split archive, or files, to SIZE kilobytes\n\
 \n\
 Controlling the shar headers:\n\
   -n, --archive-name=NAME   use NAME to document the archive\n\
@@ -2466,7 +2482,11 @@ main (int argc, char ** argv)
 
       if (intermixed_parameter_mode && (arg[0] == '-') && (arg[2] == NUL))
         {
+          int md = arg[1];
           switch (arg[1]) {
+          case 'C':
+            md = 'Z';
+            /* FALLTHROUGH */
           case 'B':
           case 'T':
           case 'M':
@@ -2475,9 +2495,9 @@ main (int argc, char ** argv)
             set_file_mode (arg[1]);
             continue;
 
-          case 'C':
-            set_file_mode ('Z');
-            continue;
+          default:
+            usage (EXIT_FAILURE);
+            /* NOTREACHED */
           }
         }
 
