@@ -2,7 +2,7 @@
 static const char cright_years_z[] =
 
 /* uudecode utility.
-   Copyright (C) */ "1994, 1995, 1996, 2002, 2005, 2006, 2007, 2010";
+   Copyright (C) */ "1994-1996, 2002, 2005-2007, 2010-2011";
 
 /* Free Software Foundation, Inc.
 
@@ -35,9 +35,6 @@ static const char cright_years_z[] =
       must display the following acknowledgement:
 	 This product includes software developed by the University of
 	 California, Berkeley and its contributors.
-   4. Neither the name of the University nor the names of its contributors
-      may be used to endorse or promote products derived from this software
-      without specific prior written permission.
 
    THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
    ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -119,8 +116,7 @@ const char *program_name;
                        } while (0)
 
 static int
-read_stduu (inname, outname)
-     const char *inname, *outname;
+read_stduu (char const * inname, char const * outname)
 {
   char buf[2 * BUFSIZ];
 
@@ -172,8 +168,7 @@ read_stduu (inname, outname)
 }
 
 static int
-read_base64 (inname, outname)
-     const char *inname, *outname;
+read_base64 (char const * inname, char const * outname)
 {
   static const char b64_tab[256] =
   {
